@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
 from json import loads
 from pyeole.process import system_out
+from creole.client import CreoleClient
+
+is_scribe = None
 
 def get_keys(*args, **kwargs):
     code, stdout, stderr = system_out(['/usr/bin/salt-key', '--out=json'], container='addc')
@@ -21,6 +24,7 @@ def get_keys(*args, **kwargs):
             res.append({"minion": key, "type": mtype})
     return res
 
+
 def accept_keys(*args, **kwargs):
     minions = kwargs['__pub_arg']
     for minion in minions:
@@ -30,15 +34,37 @@ def accept_keys(*args, **kwargs):
     ret = get_keys()
     return ret
 
+
 def delete_keys(*args, **kwargs):
-    minions = kwargs['__pub_arg']
-    for minion in minions:
+    global is_scribe
+    if is_scribe is None:
+        client = CreoleClient()
+        is_scribe = client.get_creole('openldap_installed', 'oui') == 'oui'
+    for minion in args:
+
         code, stdout, stderr = system_out(['/usr/bin/salt-key', '-d', minion['minion'], '-y'], container='addc')
         if code != 0:
             print('error:', code, stdout, stderr)
+
+        if "delmachine" in kwargs and kwargs['delmachine'] == "true":
+            if is_scribe:
+                cmd = ['ssh','-q', '-o', 'LogLevel=ERROR', '-o', 'StrictHostKeyChecking=no', 'addc']
+            else:
+                cmd = []
+            cmd.extend(['/usr/bin/samba-tool', 'computer'])
+            code, res, stderr = system_out(cmd + ['list'], container='addc')
+            if code != 0:
+                print('error:', code, stdout, stderr)
+            minname=minion['minion'].split(".")[0]
+            if minname in res :
+                todel=minname+"$"
+                code, res, stderr = system_out(cmd + ['delete', todel], container='addc')
+                if code != 0:
+                    print('error:', code, stdout, stderr)
     ret = get_keys()
     return ret
 
+
 def reject_keys(*args, **kwargs):
     minions = kwargs['__pub_arg']
     for minion in minions:
@@ -48,6 +74,7 @@ def reject_keys(*args, **kwargs):
     ret = get_keys()
     return ret
 
+
 def update_key(*args, **kwargs):
     minions = kwargs['__pub_arg']
     for minion in minions:
